<?php

namespace Drupal\cforge\Plugin\Block;

use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Block\BlockBase;
use Drupal\Core\Session\AccountInterface;

/**
 * Provides a block text social link.
 *
 * @Block(
 *   id = "social_links",
 *   admin_label = @Translation("Site social links"),
 * )
 */
final class SocialLinksBlock extends BlockBase {

  const SOCIALS = [
    'Facebook',
    'X',
    'Youtube',
    'Linkedin',
    'Github',
    'Instagram',
    'SnapChat',
    'Pinterest',
  ];

  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
    );
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state): array {

    foreach (SELF::SOCIALS as $soc_media_netwk) {
      $form[strtolower($soc_media_netwk)] = [
        '#type' => 'textfield',
        '#title' => $this->t("link for" . $soc_media_netwk),
        '#default_value' => $this->configuration['socials'][strtolower($soc_media_netwk)] ?? ""
      ];
    }
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state): void {
    $this->configuration['socials'] = [];
    foreach (SELF::SOCIALS as $soc_media_netwk) {
      $this->configuration['socials'][strtolower($soc_media_netwk)] = $form_state->getValue(strtolower($soc_media_netwk));
    }
  }

  /**
   * {@inheritdoc}
   * 
   * @note this doesn't return a render array because it has its own theme callback, social_links
   */
  public function build(): array {
    // this isn't a renderable array because it goes straight to a custom twig template.
    $build = [
      'title' => 'Suivez-nous sur les medias sociaux',
      'socials' => $this->configuration['socials'],
    ];
    return $build;
  }

  public function access(AccountInterface $account, $return_as_object = FALSE) {
    $access = \Drupal\Core\Access\AccessResult::allowedIf(!empty($this->configuration['socials']));
    return $return_as_object ? $access : $access->isAllowed();
  }
}
